package net.eusashead.hateoas.header.impl;

/*
 * #[license]
 * spring-responseentitybuilder
 * %%
 * Copyright (C) 2013 Eusa's Head
 * %%
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 * %[license]
 */

import java.util.Date;

import net.eusashead.hateoas.header.ETagHeader;
import net.eusashead.hateoas.header.ETagType;


public class ETagHeaderImpl implements ETagHeader {
	
	public static final String ETAG_HEADER = "Etag";

	private final ETagType type;

	private final String value;

	public ETagHeaderImpl(ETagType type, String value) {
		super();
		this.type = type;
		this.value = value;
	}
	
	public ETagHeaderImpl(Date date) {
		super();
		this.type = ETagType.WEAK;
		this.value = Long.valueOf(date.getTime()).toString();
	}
	
	public ETagHeaderImpl(Long version) {
		super();
		this.type = ETagType.STRONG;
		this.value = version.toString();
	}
	
	public ETagHeaderImpl(Integer version) {
		super();
		this.type = ETagType.STRONG;
		this.value = version.toString();
	}

	public ETagType getType() {
		return type;
	}
	
	@Override
	public String getName() {
		return ETAG_HEADER;
	}

	@Override
	public String getValue() {
		// Create a builder
		StringBuilder builder = new StringBuilder();

		// Is it weak validating?
		if (this.type.equals(ETagType.WEAK)) {
			builder.append("W/");
		}

		// Add the value
		builder.append('"');
		builder.append(this.value);
		builder.append('"');
		
		// Return the string
		return builder.toString();
	}

	@Override
	public String toString() {
		return getValue();
	}

}
