package net.eusashead.hateoas.response;

/*
 * #[license]
 * spring-responseentitybuilder
 * %%
 * Copyright (C) 2013 Eusa's Head
 * %%
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 * %[license]
 */

import java.util.Date;

import net.eusashead.hateoas.header.ETagHeaderStrategy;


/**
 * Create an appropriate response
 * to a HEAD request.
 * 
 * The returned entity
 * should have a status code of 
 * 204 (no content) and a null
 * body. It should return the 
 * same headers as a GET request
 * would have.
 * 
 * @author patrickvk
 *
 */
public interface HeadResponseBuilder<T> extends ResponseBuilder<Void> {
	
	/**
	 * Set the wrapped entity
	 * that this response represents
	 * @param entity
	 */
	HeadResponseBuilder<T> entity(T entity);
	
	/**
	 * Create ETag header based
	 * on the best available
	 * {@link ETagStrategy}
	 * @return
	 */
	HeadResponseBuilder<T> etag();
	
	/**
	 * Create ETag header based
	 * on the supplied
	 * {@link ETagStrategy}
	 * @return
	 */
	HeadResponseBuilder<T> etag(ETagHeaderStrategy strategy);

	/**
	 * Create a weak ETag based
	 * on the supplied date
	 * @param date
	 * @return
	 */
	HeadResponseBuilder<T> etag(Date date);

	/**
	 * Create a strong ETag based
	 * on the supplied version
	 * number
	 * @param version
	 * @return
	 */
	HeadResponseBuilder<T> etag(Integer version);
	
	/**
	 * Set the Last-Modified header
	 * based on the supplied date
	 * @param date
	 * @return
	 */
	HeadResponseBuilder<T> lastModified(Date date);
	
	/**
	 * Set the the Expires and
	 * Cache-Control headers
	 * based on the supplied 
	 * number of milliseconds
	 * @param millis
	 * @return
	 */
	HeadResponseBuilder<T> expireIn(long millis);
	
}
