package net.eusashead.hateoas.response.impl;

/*
 * #[license]
 * spring-responseentitybuilder
 * %%
 * Copyright (C) 2013 Eusa's Head
 * %%
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 * %[license]
 */

import java.util.Date;

import javax.servlet.http.HttpServletRequest;

import net.eusashead.hateoas.header.ETagHeaderStrategy;
import net.eusashead.hateoas.response.PutResponseBuilder;

import org.springframework.http.HttpStatus;
import org.springframework.http.ResponseEntity;

public class PutResponseBuilderImpl<T> extends AbstractEntityResponseBuilder<Void, T> implements PutResponseBuilder<T> {

	private boolean isCreate = false;
	
	public PutResponseBuilderImpl(HttpServletRequest request) {
		super(request);
	}

	@Override
	public ResponseEntity<Void> build() {
		ResponseEntity<Void> responseEntity;
		if (isCreate) {
			responseEntity = new ResponseEntity<Void>(this.headers, HttpStatus.CREATED);
		} else {
			responseEntity = new ResponseEntity<Void>(this.headers, HttpStatus.NO_CONTENT);
		}
		return responseEntity;
	}

	@Override
	public PutResponseBuilder<T> entity(T entity) {
		super.setEntity(entity);
		return this;
	}

	@Override
	public PutResponseBuilder<T> etag() {
		super.setEtagHeader();
		return this;
	}

	@Override
	public PutResponseBuilder<T> etag(ETagHeaderStrategy strategy) {
		super.setEtagHeader(strategy);
		return this;
	}

	@Override
	public PutResponseBuilder<T> etag(Date date) {
		super.setEtagHeader(date);
		return this;
	}

	@Override
	public PutResponseBuilder<T> etag(Integer version) {
		super.setEtagHeader(version);
		return this;
	}

	@Override
	public PutResponseBuilder<T> lastModified(Date date) {
		super.setLastModifiedHeader(date);
		return this;
	}

	@Override
	public PutResponseBuilder<T> isCreate() {
		this.isCreate = true;
		return this;
	}

}
